Modules
- chat
- This file defines the TextComponent type in the Minecraft network API. Seen in books, disconnect messages, chat messages, action bar, etc.
- nbt
- var_
types - The purpose of this file is to define the custom integer types for the Minecraft protocol, VarInt and VarLong. See more details here: https://wiki.vg/Protocol#VarInt_and_VarLong